name = "pdb_tools"
__all__ = ["biobb_pdb_fetch", "biobb_pdb_reres", "biobb_pdb_chain", "biobb_pdb_chainxseg", "biobb_pdb_delhetatm", "biobb_pdb_merge", "biobb_pdb_mkensemble", "biobb_pdb_seg", "biobb_pdb_splitmodel", "biobb_pdb_splitseg", "biobb_pdb_tidy", "biobb_pdb_uniqname"]



#!/usr/bin/env python3

"""Module containing the Pdbfetch class and the command line interface."""
import argparse
from biobb_common.generic.biobb_object import BiobbObject
from biobb_common.configuration import settings
from biobb_common.tools import file_utils as fu
from biobb_common.tools.file_utils import launchlogger


class Pdbfetch(BiobbObject):
    """
    | biobb_pdb_tools Pdbfetch
    | Downloads a structure in PDB format from the RCSB website.

    Args:
        output_file_path (str): PDB file of the protein selected. File type: output. `Sample file <https://raw.githubusercontent.com/bioexcel/biobb_pdb_tools/master/biobb_pdb_tools/test/reference/pdb_tools/ref_pdb_fetch.pdb>`_. Accepted formats: pdb (edam:format_1476).
        properties (dic):
            * **pdbid** (*string*) - ('1aki') ID of the protein.
            * **biounit** (*string*) - (False) Allows downloading the (first) biological structure if selected.
            * **binary_path** (*str*) - ("pdb_fetch") Path to the pdb_fetch executable binary.
            * **remove_tmp** (*bool*) - (True) [WF property] Remove temporal files.
            * **restart** (*bool*) - (False) [WF property] Do not execute if output files exist.

    Examples:
        This is a use example of how to use the building block from Python::

            from biobb_pdb_tools.pdb_tools.biobb_pdb_fetch import biobb_pdb_fetch

            prop = {
                'biounit': False,
                'pdbid': '1aki'
            }
            biobb_pdb_fetch(output_file_path='/path/to/file.pdb',
                    properties=prop)

    Info:
        * wrapped_software:
            * name: pdb_tools
            * version: >=2.5.0
            * license: Apache-2.0
        * ontology:
            * name: EDAM
            * schema: http://edamontology.org/EDAM.owl

    """

    def __init__(self, output_file_path, properties=None, **kwargs) -> None:
        properties = properties or {}

        super().__init__(properties)
        self.locals_var_dict = locals().copy()
        self.io_dict = {
            'out': {'output_file_path': output_file_path}
        }

        self.pdbid = properties.get('pdbid', '1aki')
        self.binary_path = properties.get('binary_path', 'pdb_fetch')
        self.biounit = properties.get('biounit', False)
        self.properties = properties

        self.check_properties(properties)
        self.check_arguments()

    @launchlogger
    def launch(self) -> int:
        """Execute the :class:`Pdbfetch <biobb_pdb_tools.pdb_tools.pdb_fetch>` object."""

        if self.check_restart():
            return 0
        instructions = []
        if self.biounit:
            instructions.append('-biounit')
            fu.log('Appending optional boolean property', self.out_log, self.global_log)

        self.cmd = [self.binary_path, ' '.join(instructions), self.pdbid, '>', self.io_dict['out']['output_file_path']]

        fu.log(self.cmd, self.out_log, self.global_log)

        fu.log('Creating command line with instructions and required arguments', self.out_log, self.global_log)

        self.run_biobb()
        self.copy_to_host()

        self.tmp_files.extend([
            self.stage_io_dict.get("unique_dir")
        ])
        self.remove_tmp_files()

        self.check_arguments(output_files_created=True, raise_exception=False)
        return self.return_code


def biobb_pdb_fetch(output_file_path: str, properties: dict = None, **kwargs) -> int:
    """Create :class:`Pdbfetch <biobb_pdb_tools.pdb_tools.pdb_fetch>` class and
    execute the :meth:`launch() <biobb_pdb_tools.pdb_tools.pdb_fetch.launch>` method."""
    return Pdbfetch(output_file_path=output_file_path,
                    properties=properties, **kwargs).launch()


def main():
    """Command line execution of this building block. Please check the command line documentation."""
    parser = argparse.ArgumentParser(description='Downloads a structure in PDB format from the RCSB website.', formatter_class=lambda prog: argparse.RawTextHelpFormatter(prog, width=99999))
    parser.add_argument('--config', required=True, help='Configuration file')

    required_args = parser.add_argument_group('required arguments')
    required_args.add_argument('--output_file_path', required=True, help='Description for the output file path. Accepted formats: zip.')

    args = parser.parse_args()
    args.config = args.config or "{}"
    properties = settings.ConfReader(config=args.config).get_prop_dic()

    biobb_pdb_fetch(output_file_path=args.output_file_path, properties=properties)


if __name__ == '__main__':
    main()



#!/usr/bin/env python3

"""Module containing the Pdbmerge class and the command line interface."""
import argparse
from biobb_common.generic.biobb_object import BiobbObject
from biobb_common.configuration import settings
from biobb_common.tools import file_utils as fu
from biobb_common.tools.file_utils import launchlogger
import os
import zipfile
from pathlib import Path


class Pdbmerge(BiobbObject):
    """
    | biobb_pdb_tools Pdbmerge
    | Merges several PDB files into one.

    Args:
        input_file_path (str): ZIP file of selected protein. File type: input. `Sample file <https://raw.githubusercontent.com/bioexcel/biobb_pdb_tools/master/biobb_pdb_tools/test/data/pdb_tools/input_pdb_merge1.pdb>`_. Accepted formats: zip (edam:format_3987).
        output_file_path (str): PDB file with input PDBs merged. File type: output. `Sample file <https://raw.githubusercontent.com/bioexcel/biobb_pdb_tools/master/biobb_pdb_tools/test/reference/pdb_tools/ref_pdb_merge.pdb>`_. Accepted formats: pdb (edam:format_1476).
        properties (dic):
            * **binary_path** (*str*) - ("pdb_merge") Path to the pdb_merge executable binary.
            * **remove_tmp** (*bool*) - (True) [WF property] Remove temporal files.
            * **restart** (*bool*) - (False) [WF property] Do not execute if output files exist.

    Examples:
        This is a use example of how to use the building block from Python::

            from biobb_pdb_tools.pdb_tools.biobb_pdb_merge import biobb_pdb_merge

            biobb_pdb_merge(input_file_path='/path/to/input1.zip',
                    output_file_path='/path/to/output.pdb')

    Info:
        * wrapped_software:
            * name: pdb_tools
            * version: >=2.5.0
            * license: Apache-2.0
        * ontology:
            * name: EDAM
            * schema: http://edamontology.org/EDAM.owl

    """
    def __init__(self, input_file_path, output_file_path, properties=None, **kwargs) -> None:
        properties = properties or {}

        super().__init__(properties)
        self.locals_var_dict = locals().copy()

        self.io_dict = {
            'in': {'input_file_path': input_file_path},
            'out': {'output_file_path': output_file_path}
        }

        self.binary_path = properties.get('binary_path', 'pdb_merge')
        self.properties = properties

        self.check_properties(properties)
        self.check_arguments()

    @launchlogger
    def launch(self) -> int:
        """Execute the :class:`Pdbmerge <biobb_pdb_tools.pdb_tools.pdb_merge>` object."""

        if self.check_restart():
            return 0
        self.stage_files()

        input_file_path = self.stage_io_dict['in']['input_file_path']
        folder_path = os.path.dirname(input_file_path)

        if zipfile.is_zipfile(input_file_path):
            with zipfile.ZipFile(input_file_path, 'r') as zip_ref:
                zip_ref.extractall(folder_path)

            pdb_files = [file for file in os.listdir(folder_path) if file.lower().endswith('.pdb')]

            input_file_list = [os.path.join(folder_path, file) for file in pdb_files]

            input_file_list = [Path(i) for i in input_file_list]
            input_file_list = sorted(input_file_list, key=lambda i: i.stem.upper())
            input_file_list = [str(i) for i in input_file_list]

            self.cmd = [self.binary_path, *input_file_list, '>', self.io_dict['out']['output_file_path']]

        else:
            fu.log(f"The archive {input_file_path} is not a ZIP!", self.out_log, self.global_log)

        fu.log(self.cmd, self.out_log, self.global_log)

        fu.log('Creating command line with instructions and required arguments', self.out_log, self.global_log)

        self.run_biobb()
        self.copy_to_host()

        self.tmp_files.extend([
            self.stage_io_dict.get("unique_dir")
        ])
        self.remove_tmp_files()
        self.check_arguments(output_files_created=True, raise_exception=False)

        return self.return_code


def biobb_pdb_merge(input_file_path: str, output_file_path: str, properties: dict = None, **kwargs) -> int:
    """Create :class:`Pdbmerge <biobb_pdb_tools.pdb_tools.pdb_merge>` class and
    execute the :meth:`launch() <biobb_pdb_tools.pdb_tools.pdb_merge.launch>` method."""
    return Pdbmerge(input_file_path=input_file_path,
                    output_file_path=output_file_path,
                    properties=properties, **kwargs).launch()


def main():
    """Command line execution of this building block. Please check the command line documentation."""
    parser = argparse.ArgumentParser(description='Merges several PDB files into one.', formatter_class=lambda prog: argparse.RawTextHelpFormatter(prog, width=99999))
    parser.add_argument('--config', required=True, help='Configuration file')

    required_args = parser.add_argument_group('required arguments')
    required_args.add_argument('--input_file_path', required=True, help='Description for the first input file path. Accepted formats: pdb.')
    required_args.add_argument('--output_file_path', required=True, help='Description for the output file path. Accepted formats: zip.')

    args = parser.parse_args()
    args.config = args.config or "{}"
    properties = settings.ConfReader(config=args.config).get_prop_dic()
    biobb_pdb_merge(input_file_path=args.input_file_path, output_file_path=args.output_file_path, properties=properties)


if __name__ == '__main__':
    main()



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="biobb_pdb_tools",
    version="4.1.1",
    author="Biobb developers",
    author_email="agustin.garcia@irbbarcelona.org",
    description="Biobb_pdb_tools is a swiss army knife for manipulating and editing PDB files.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    keywords="Bioinformatics Workflows BioExcel Compatibility",
    url="https://github.com/bioexcel/biobb_pdb_tools",
    project_urls={
        "Documentation": "http://biobb-pdb-tools.readthedocs.io/en/latest/",
        "Bioexcel": "https://bioexcel.eu/"
    },
    packages=setuptools.find_packages(exclude=['docs', 'test']),
    install_requires=['biobb_common==4.1.0'],
    python_requires='>=3.8',
    entry_points={
        "console_scripts": [
            "biobb_pdb_chain = biobb_pdb_tools.pdb_tools.biobb_pdb_chain:main",
            "biobb_pdb_chainxseg = biobb_pdb_tools.pdb_tools.biobb_pdb_chainxseg:main",
            "biobb_pdb_delhetatm = biobb_pdb_tools.pdb_tools.biobb_pdb_delhetatm:main",
            "biobb_pdb_fetch = biobb_pdb_tools.pdb_tools.biobb_pdb_fetch:main",
            "biobb_pdb_merge = biobb_pdb_tools.pdb_tools.biobb_pdb_merge:main",
            "biobb_pdb_mkensemble = biobb_pdb_tools.pdb_tools.biobb_pdb_mkensemble:main",
            "biobb_pdb_reres = biobb_pdb_tools.pdb_tools.biobb_pdb_reres:main",
            "biobb_pdb_seg = biobb_pdb_tools.pdb_tools.biobb_pdb_seg:main",
            "biobb_pdb_splitmodel = biobb_pdb_tools.pdb_tools.biobb_pdb_splitmodel:main",
            "biobb_pdb_splitseg = biobb_pdb_tools.pdb_tools.biobb_pdb_splitseg:main",
            "biobb_pdb_tidy = biobb_pdb_tools.pdb_tools.biobb_pdb_tidy:main",
            "biobb_pdb_tofasta = biobb_pdb_tools.pdb_tools.biobb_pdb_tofasta:main",
            "biobb_pdb_uniqname = biobb_pdb_tools.pdb_tools.biobb_pdb_uniqname:main"
        ]
    },
    classifiers=(
        "Development Status :: 5 - Production/Stable",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: POSIX",
        "Operating System :: Unix"
    ),
)
